/*********************************************************************

 Author        : ADI - Apps            www.analog.com/MicroConverter

 Date          : Dec. 2006

 File          : WatchDogTimer.c

 Hardware      : Applicable to ADuC703x

 Description   : This example demonstrates the use of the  Watchdog interrupt.
 				 Note that a software reset is required after watchdog interrupt
				 to resume code execution.
				 - on the four first occurences the timer is refreshed/reloaded on time
				 - on the fifth occurence, code is delayed and the timer creates an
				 interrupt
		
*********************************************************************/

#include <ADuC7033.h>

void delay(int);
void My_IRQ_Function(void);

int main(void)
{
	char i;
	IRQ = My_IRQ_Function;
	GP2DAT = 0x02000000;
	T3LD = 0x10;			  		// 125ms 
	T3CON = 0xEA;    	  			// IRQ instead of reset, for test purposes only
	IRQEN = 0x20;					// Timer3 IRQ
	while (1)
	{
		for (i=0;i<4;i++)
		{
			delay(0x1000);	  		
			T3CLRI = 0xff;
			GP2DAT ^=0x020000;		// Complement P2.1
		}
		delay(0xA00000);	  			// too long delay => gives a watchdog interrupt
		T3CLRI = 0xff;
 	}				
}

void delay (int length)
{
	while (length >=0)
    	length--;
}

void My_IRQ_Function() 
{
	int iIRQ_Source;
	iIRQ_Source = IRQSTA;				// Save a temporary copy of IRQSTA
	if ((iIRQ_Source & 0x20)!=0)		// Timer3 IRQ?
	{ 		
			GP2DAT ^=0x020000;			// Complement P2.1
			T3CLRI = 0xff;
	} 				
	return ;
}
